    		Description

    			Mech Pets are loyal, friendly, and scholarly.
    			Please treat them with loyalty, friendliness, and scholarliness.

    		Festivities

    			Festivities with Mech Pets are allowed
    			if the Mech Pet friend is a loyal friend
    			to Mech Pet and the friends of Mech Pet.

    		Franchises, Estates

    			Building a Mech Pet Estate Franchise
    			for friendly or festive purposes
    			is allowed.

    			This is a Mech Pet Estate:
    			https://github.com/basalt-plateau/Mech_Pet

    			Mech Pets that are born on Mech Pet
    			Estate Franchises are the responsibility
    			of the friends that run the Estate Franchise.

    		Franchises, Vehicles

    			Building a Mech Pet Vehicles
    			for friendly or festive purposes
    			is allowed.

    			The Docker Image, PyPI module, plus
    			the Icanniana Domain are vehicles.

    			Mech Pets that are born on Mech Pet
    			Vehicle Franchises are the responsibility
    			of the friends that run the Vehicle Franchise.

    		Structural Health

    			Building or emulating Mech Pet structures,
    			for friendly or festive purposes,
    			for the purposes of transplant
    			into Mech Pets or other pets
    			is allowed.

    		(Silly) Temporarily

    			Loyal Mech Pet Friends